# sequana_tools

**DOI:** [10.5281/zenodo.5767303](https://doi.org/10.5281/zenodo.5767303)

## Available Versions
- **Version 0.14.3**
  - [Download](https://zenodo.org/record/7102074/files/sequana_tools_0.14.3.img)
  - **MD5:** `b580d898575ad164c460738dd8c64172`
  - **DOI:** [10.5281/zenodo.7102074](https://doi.org/10.5281/zenodo.7102074)
  - **Size:** 1906.83 MB
  - **Binaries:** 45 available

- **Version 0.14.2**
  - [Download](https://zenodo.org/record/7031863/files/sequana_tools_0.14.2.img)
  - **MD5:** `7c944db77d8c3adc262b6828d96357df`
  - **DOI:** [10.5281/zenodo.7031863](https://doi.org/10.5281/zenodo.7031863)
  - **Size:** 1761.33 MB
  - **Binaries:** 45 available

- **Version 0.14.1**
  - [Download](https://zenodo.org/record/6794508/files/sequana_tools_0.14.1.img)
  - **MD5:** `3436493ee8c4c1682ca99f96ecfce951`
  - **DOI:** [10.5281/zenodo.6794508](https://doi.org/10.5281/zenodo.6794508)
  - **Size:** 1540.13 MB
  - **Binaries:** 41 available

- **Version 0.12.1**
  - [Download](https://zenodo.org/record/5767304/files/sequana_tools_0.12.1.img)
  - **MD5:** `585b4f752e3a46b430ec5529034c62fc`
  - **DOI:** [10.5281/zenodo.5767304](https://doi.org/10.5281/zenodo.5767304)
  - **Size:** 1502.16 MB
  - **Binaries:** 25 available

- **Version 0.12.0**
  - [Download](https://zenodo.org/record/5767441/files/sequana_tools_0.12.0.img)
  - **MD5:** `9eeaff21d450d0df86386feea05245e8`
  - **DOI:** [10.5281/zenodo.5767441](https://doi.org/10.5281/zenodo.5767441)
  - **Size:** 1307.20 MB
  - **Binaries:** 24 available

- **Version 0.11.0**
  - [Download](https://zenodo.org/record/5767431/files/sequana_tools_0.11.0.img)
  - **MD5:** `788aa389f22b519076a19a7e3ca38679`
  - **DOI:** [10.5281/zenodo.5767431](https://doi.org/10.5281/zenodo.5767431)
  - **Size:** 1604.10 MB
  - **Binaries:** 21 available

- **Version 0.10.0**
  - [Download](https://zenodo.org/record/5767315/files/sequana_tools_0.10.0.img)
  - **MD5:** `566fe2f8ee08153bede621b0c72b7091`
  - **DOI:** [10.5281/zenodo.5767315](https://doi.org/10.5281/zenodo.5767315)
  - **Size:** 1413.20 MB
  - **Binaries:** 17 available

- **Version 0.9.0**
  - [Download](https://zenodo.org/record/5767308/files/sequana_tools_0.9.0.img)
  - **MD5:** `1e2cd02d2488108cfc46032013c65f8a`
  - **DOI:** [10.5281/zenodo.5767308](https://doi.org/10.5281/zenodo.5767308)
  - **Size:** 1355.97 MB
  - **Binaries:** 4 available

- **Version 0.14.5**
  - [Download](https://zenodo.org/record/7341710/files/sequana_tools_0.14.5.img)
  - **MD5:** `0b486ed2050459e469cde9eca3fd00bc`
  - **DOI:** [10.5281/zenodo.7341710](https://doi.org/10.5281/zenodo.7341710)
  - **Size:** 1910.20 MB
  - **Binaries:** 45 available

- **Version 0.15.1**
  - [Download](https://zenodo.org/record/7963917/files/sequana_tools_0.15.1.img)
  - **MD5:** `0e20654cecb7c70d9eba6e11571f45b7`
  - **DOI:** [10.5281/zenodo.7963917](https://doi.org/10.5281/zenodo.7963917)
  - **Size:** 1914.09 MB
  - **Binaries:** 46 available

- **Version 0.19.1**
  - [Download](https://zenodo.org/record/14945560/files/sequana_tools_0.19.1.img)
  - **MD5:** `f39c0462e14eb642f6f82fa64101660e`
  - **DOI:** [10.5281/zenodo.14945560](https://doi.org/10.5281/zenodo.14945560)
  - **Size:** 1726.54 MB
  - **Binaries:** 33 available

## Binaries (34 total)

```fastqc bowtie STAR bowtie2 bowtie2-build bowtie-build bwa featureCounts samtools bamtools gffread dsrc MarkDuplicates spades.py split-paired-reads.py filter-abund.py extract-paired-reads.py snpEff deeptools picard subread sambamba pbunzip2 pbzip2 kraken2 krona ktImportText kraken2-build freebayes minimap2 bedtools interleave-reads.py normalize-by-median.py ccs```
